@@ -1,7 +1,6 @@
 package Weed::Parser;
-use Weed::Perl;
-
-our $VERSION = '0.009';
+use strict;
+use warnings;
 
 use Carp qw(croak);
 
