@@ -2,7 +2,9 @@ package Weed::Seed;
 use strict;
 use warnings;
 
-use base 'Weed::Universal';
+use Weed::Universal;
+use base 'X3DUniversal';
+use Weed::Universal 'X3DObject { }';
 
 use Weed::Generator::Symbols;
 
@@ -13,8 +15,6 @@ use overload
   'ne' => sub { $_[1] ne "$_[0]" },
   ;
 
-our $DESCRIPTION = 'X3DObject { }';
-
 sub new {
 	my ( $self, $type ) = @_;
 	my $this = $self->NEW({});
